@@ -5,23 +5,22 @@
 
 typedef struct flags flags;
 
-struct flags
-{
-  bool active:1;
-  bool backbone0:1;
-  bool backbone1:1;
-  bool eliminate:1;
-  bool eliminated:1;
-  bool fixed:1;
-  bool subsume:1;
-  bool sweep:1;
+struct flags {
+  bool active : 1;
+  bool backbone0 : 1;
+  bool backbone1 : 1;
+  bool eliminate : 1;
+  bool eliminated : 1;
+  bool fixed : 1;
+  bool subsume : 1;
+  bool sweep : 1;
+  bool transitive : 1;
 };
 
-#define FLAGS(IDX) \
-  (assert ((IDX) < VARS), (solver->flags + (IDX)))
+#define FLAGS(IDX) (assert ((IDX) < VARS), (solver->flags + (IDX)))
 
-#define ACTIVE(IDX) (FLAGS(IDX)->active)
-#define ELIMINATED(IDX) (FLAGS(IDX)->eliminated)
+#define ACTIVE(IDX) (FLAGS (IDX)->active)
+#define ELIMINATED(IDX) (FLAGS (IDX)->eliminated)
 
 struct kissat;
 
