@@ -1,17 +1,16 @@
+#include "probe.h"
 #include "backbone.h"
 #include "backtrack.h"
 #include "internal.h"
 #include "print.h"
-#include "probe.h"
 #include "substitute.h"
 #include "sweep.h"
+#include "transitive.h"
 #include "vivify.h"
 
 #include <inttypes.h>
 
-bool
-kissat_probing (kissat * solver)
-{
+bool kissat_probing (kissat *solver) {
   if (!solver->enabled.probe)
     return false;
   if (solver->waiting.probe.reduce > solver->statistics.reductions)
@@ -19,27 +18,24 @@ kissat_probing (kissat * solver)
   return solver->limits.probe.conflicts <= CONFLICTS;
 }
 
-static void
-probe (kissat * solver)
-{
+static void probe (kissat *solver) {
   kissat_backtrack_propagate_and_flush_trail (solver);
   assert (!solver->inconsistent);
   STOP_SEARCH_AND_START_SIMPLIFIER (probe);
   kissat_phase (solver, "probe", GET (probings),
-		"probing limit hit after %" PRIu64 " conflicts",
-		solver->limits.probe.conflicts);
+                "probing limit hit after %" PRIu64 " conflicts",
+                solver->limits.probe.conflicts);
   kissat_substitute (solver);
   kissat_binary_clauses_backbone (solver);
   kissat_vivify (solver);
   kissat_sweep (solver);
   kissat_substitute (solver);
+  kissat_transitive_reduction (solver);
   kissat_binary_clauses_backbone (solver);
   STOP_SIMPLIFIER_AND_RESUME_SEARCH (probe);
 }
 
-int
-kissat_probe (kissat * solver)
-{
+int kissat_probe (kissat *solver) {
   assert (!solver->inconsistent);
   INC (probings);
   assert (!solver->probing);
